==> remixd-0.0.5.tgz: package/src/services/systemFiles.js <==
var utils = require('../utils')
var isbinaryfile = require('isbinaryfile')
var fs = require('fs-extra')
var watch = require('watch')

module.exports = {
  filesChanged: {},

  list: function (args, cb) {
    cb(null, utils.walkSync(process.argv[2]))
  },

  get: function (args, cb) {
    var path = utils.absolutePath(args.path)
    isbinaryfile(path, (error, isBinary) => {
      if (error) console.log(error)
      if (isBinary) {
        cb(null, '<binary content not displayed>')
      } else {
        fs.readFile(path, 'utf8', (error, data) => {
          if (error) console.log(error)
          cb(error, data)
        })
      }
    })
  },

  set: function (args, cb) {
    var path = utils.absolutePath(args.path)
    this.filesChanged[path] = args.content
    fs.writeFile(path, args.content, 'utf8', (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  rename: function (args, cb) {
    var oldpath = utils.absolutePath(args.oldPath)
    var newpath = utils.absolutePath(args.newPath)
    fs.move(process.argv[2] + '/' + oldpath, process.argv[2] + '/' + newpath, (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  remove: function (args, cb) {
    var path = utils.absolutePath(args.path)
    fs.remove(path, (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  setupNotifications: function (websocket) {
    watch.createMonitor(process.argv[2], (monitor) => {
      monitor.on('created', (f, stat) => {
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'created', value: utils.relativePath(f)}))
      })
      monitor.on('changed', (f, curr, prev) => {
        if (this.filesChanged[f]) { // has been changed by upstream. no need to send notification
          delete this.filesChanged[f]
          return
        }
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'changed', value: utils.relativePath(f)}))
      })
      monitor.on('removed', (f, stat) => {
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'removed', value: utils.relativePath(f)}))
      })
    })
  }
}

==> remixd-0.0.6.tgz: package/src/services/systemFiles.js <==
var utils = require('../utils')
var isbinaryfile = require('isbinaryfile')
var fs = require('fs-extra')
var watch = require('watch')

module.exports = {
  filesChanged: {},

  list: function (args, cb) {
    console.log(utils.walkSync(process.argv[2]))
    cb(null, utils.walkSync(process.argv[2]))
  },

  get: function (args, cb) {
    var path = utils.absolutePath(args.path)
    isbinaryfile(path, (error, isBinary) => {
      if (error) console.log(error)
      if (isBinary) {
        cb(null, '<binary content not displayed>')
      } else {
        fs.readFile(path, 'utf8', (error, data) => {
          if (error) console.log(error)
          cb(error, data)
        })
      }
    })
  },

  set: function (args, cb) {
    var path = utils.absolutePath(args.path)
    this.filesChanged[path] = args.content
    fs.writeFile(path, args.content, 'utf8', (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  rename: function (args, cb) {
    var oldpath = utils.absolutePath(args.oldPath)
    var newpath = utils.absolutePath(args.newPath)
    fs.move(oldpath, newpath, (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  remove: function (args, cb) {
    var path = utils.absolutePath(args.path)
    fs.remove(path, (error, data) => {
      if (error) console.log(error)
      cb(error, data)
    })
  },

  setupNotifications: function (websocket) {
    watch.createMonitor(process.argv[2], (monitor) => {
      monitor.on('created', (f, stat) => {
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'created', value: utils.relativePath(f)}))
      })
      monitor.on('changed', (f, curr, prev) => {
        if (this.filesChanged[f]) { // has been changed by upstream. no need to send notification
          delete this.filesChanged[f]
          return
        }
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'changed', value: utils.relativePath(f)}))
      })
      monitor.on('removed', (f, stat) => {
        if (websocket.connection) websocket.send(JSON.stringify({type: 'notification', scope: 'systemfiles', name: 'removed', value: utils.relativePath(f)}))
      })
    })
  }
}
